==> json-joy-2.5.3.tgz: package/esm/json-rx/JsonRpcRxServer.js <==
import { assertId, assertName, isArray } from './util';
export class JsonRpcRxServer {
    constructor({ call, notify }) {
        this.call = call;
        this.notify = notify;
    }
    async onSubscribe(ctx, message) {
        const [id, name, payload] = message;
        assertId(id);
        assertName(name);
        const result = await this.call(name, ctx, payload);
        return [0, id, result];
    }
    onNotification(ctx, message) {
        const [name, payload] = message;
        assertName(name);
        this.notify(name, ctx, payload);
    }
    async onMessage(ctx, message) {
        try {
            if (!isArray(message))
                throw new Error('Invalid message');
            if (!message.length)
                return null;
            if (isArray(message[0]))
                return await Promise.all(message.map(msg => this.onMessage(ctx, msg)));
            const [one] = message;
            if (typeof one === 'string') {
                this.onNotification(ctx, message);
                return null;
            }
            if (one > 0)
                return await this.onSubscribe(ctx, message);
            throw new Error('Invalid message');
        }
        catch (error) {
            const id = isArray(message) && (typeof message[0] === 'number') && (message[0] > 0) && (Math.round(message[0]) === message[0])
                ? message[0] : -1;
            return [-1, id, { message: error instanceof Error ? error.message : String(error) }];
        }
    }
}

==> json-joy-2.17.0.tgz: package/esm/json-rx/JsonRpcRxServer.js <==
import { assertId, assertName, isArray } from './util';
export class JsonRpcRxServer {
    constructor({ call, notify }) {
        this.call = call;
        this.notify = notify;
    }
    async onSubscribe(ctx, message) {
        const [id, name, payload] = message;
        assertId(id);
        assertName(name);
        const result = await this.call(name, ctx, payload);
        return [0, id, result];
    }
    onNotification(ctx, message) {
        const [name, payload] = message;
        assertName(name);
        this.notify(name, ctx, payload);
    }
    async onMessage(ctx, message) {
        try {
            if (!isArray(message))
                throw new Error('Invalid message');
            if (!message.length)
                return null;
            if (isArray(message[0]))
                return (await Promise.all(message.map((msg) => this.onMessage(ctx, msg))));
            const [one] = message;
            if (typeof one === 'string') {
                this.onNotification(ctx, message);
                return null;
            }
            if (one > 0)
                return await this.onSubscribe(ctx, message);
            throw new Error('Invalid message');
        }
        catch (error) {
            const id = isArray(message) && typeof message[0] === 'number' && message[0] > 0 && Math.round(message[0]) === message[0]
                ? message[0]
                : -1;
            return [-1, id, { message: error instanceof Error ? error.message : String(error) }];
        }
    }
}
